# 模板语法指南 (NB 模板)

本文档说明 mark2pdf 内置 NB (Notebook) 模板支持的扩展语法。你可以使用这些语法创建整页图片、多栏布局、特殊引用块等效果。

## 1. 布局类

### 全页图片 (Fullimage)

创建一张占据整页的图片，自动分页。

```markdown
::: {#fullimage}
images/photo.jpg
fit=cover
:::
```
- **第一行**: 图片路径。
- **`fit`**: `cover` (铺满裁切), `contain` (完整显示), `stretch` (拉伸)。

### 顶部/底部出血图 (Topimage / Bottomimage)

在页面顶部或底部创建无边距的出血图片。

```markdown
::: {#topimage}
images/header.jpg
:::

::: {#bottomimage}
images/footer.jpg
:::
```

### 全宽内容 (Fullwidth)

打破正文边界，让内容（通常是宽图）延展到页面右侧边缘。

```markdown
::: {#fullwidth}
![](images/wide-chart.png)
:::
```

---

## 2. 页面类

### 概览页 (Overview)

用于章节开头或过渡页，通常带有底色。

```markdown
::: {#overview}
fill=#EEF0F4

# 第二章
这里是本章的摘要介绍...
:::
```

### 背景页 (Pagebg)

为特定页面设置背景图。

```markdown
::: {#pagebg}
bg=images/paper-texture.jpg

# 页面内容
...
:::
```

---

## 3. 组件类

### 行动引用 (Action)

特殊的引用样式，无底色，适合强调行动建议。

```markdown
::: {#action}
> 这是一个需要注意的行动点。
:::
```

### 浮动评论 (Comments)

```markdown
::: {#floatcomment}
这是右侧边缘的批注。
:::
```

---

## 4. 封面与主题

通过 Frontmatter 的 `theme` 字段控制。

```yaml
theme:
  coverstyle: "darkbg"      # 封面样式: default, report, darkbg
  coverbg: "images/bg.jpg"  # darkbg 模式下的背景图
  backcoverstyle: "biglogo" # 封底样式
```
